/*!
* @fileoverview
*    全局的JS 文件，用来写一些公共的方法，和配置等等
*
* @Author Dehua.ke
* @Email kedh@hzzh.com
* @Date 2018/08/06
*
* Copyright 2018 中恒节能 Inc. All Rights Reserved.
*/
var ZH = (function (MUI, WIN, gAjax) {
    /**
     *
     * 打开一个页面
     *
     * */
    function openPage(url, id) {
        MUI.openWindow({
            url: url,
            id: id,
            waiting: {
                autoShow: false, //自动显示等待框，默认为true
            }
        })
    }

    /**
     *   根据 webview ID 来决定是创建一个新的视图，还是触发自定义事件
     *
     * @param webviewId   一个 webviewId，用来判断该 webview是否被创建过
     * @param update   String|function
     *          String : 自定义事件名你需要触发的自定义事件名
     *          function : 自定义回调
     * @param create    function : 自定义回调，用来创建该视图的方法
     *
     *
     */
    function updateOrCreateByWebviewId(webviewId, update, create, data) {
        //获得 map界面的webview
        var theWebView = plus.webview.getWebviewById(webviewId);
        //已经创建过该 webview
        if (theWebView !== null) {
            //触发列表界面的自定义事件（refresh）,从而进行数据刷新
            if ("string" === typeof update) {
                mui.fire(theWebView, update, data);
            } else {
                update();
            }
        }
        //没有创建过底部面板
        else {
            create();
        }
    }
	//验证码校验
	function imgCode(phone, appId, imgCode, guuid, callback) {
		var url = "/charge-app-server/app/user/getCode/" + phone;
		gAjax.$http({
			url: url,
			data: {
				appId: appId,
				imgCode: imgCode,
				uuid: guuid
				
			},
			methods: 'GET',
			success: callback,
		});
	}
	//发送验证码
	function gCode(phone,appId,imgCode, callback) {
		var url = "/charge-app-server/app/user/getCode/" + phone;
		gAjax.$http({
			url: url,
			data: {
				appId: appId,
				imgCode: imgCode,
				
			},
			methods: 'GET',
			success: callback,
		});
	}

    //获取用户信息
    function getAccount(callback) {
        gAjax.$http({
            url: "/charge-app-server/app/account/getAccount",
            methods: 'GET',
            success: callback,
        })
    }
    // 电费 保留两位小数2.00000元/度
	function priceFixed(pricesStr){
		var priceNum = pricesStr?pricesStr.substring(0,pricesStr.indexOf("元")):0;
	      return priceNum;//Number(priceNum).toFixed(2);
	}
	/* 充电按钮禁用条件
	  	1: "空闲可用",
        2: "故障",
        3: "离线",
        4: "充电中",
        5: "自检中"
    */
	function chargeBtnDisabled(operatingStatus,hasOffline){
		if(hasOffline){
			return false;
		}
        if (operatingStatus == 2 || operatingStatus == 4 || operatingStatus == 5) {
            return true;
        } else {
            return false;
        }
	}
    //检查充电桩 枪口状态
    function checkPortStatus(devCode, port, selectedPortName,togetherChargeType, isCheckCb) {
        console.log(devCode + '&port=' + port + '&togetherChargeType=' + togetherChargeType+'枪口状态')
        var _this = this;
        gAjax.$http({
            url: '/charge-app-server/app/charge/checkPortStatus?devCode=' + devCode + '&port=' + port + '&togetherChargeType=' + togetherChargeType,
            methods: 'get',
            success: function (res) {
                console.log(JSON.stringify(res)+"77777777777777777777777")
                var errorPort = "";
                if(res.data&&res.data.length!=0){
                    errorPort = res.data.join('');
                }
                switch (res.status) {
                    case 200:
                        isCheckCb(true)
                        break;
                    case 21001://枪故障 21001
                        plus.nativeUI.alert(errorPort + "枪突发故障，请选择其他可用枪充电！", function () {
                        }, "", "知道了");
                        isCheckCb(false);
                        break;
                    case 21002://枪占用21002
                        plus.nativeUI.alert(errorPort + "枪已被占用，请选择其他枪进行充电！", function () {
                        }, "", "知道了");
                        isCheckCb(false);
                        break;
                    case 21003://21003 枪没插好
                            //充电模式:1单充 2并充
                        if(togetherChargeType == 2){
                            plus.nativeUI.alert(errorPort + "枪未插枪，并充需要双枪枪都插好才能充电！", function () {
                            }, "", "确认");
                        }else{
                             plus.nativeUI.alert(errorPort + "充电枪未插好，系统无法完成自检充电，请检查并确认枪已插好。", function () {
                            }, "", "确认插枪");
                        }
                        
                        isCheckCb(false);
                        break;
                    case 21004://21004 桩不存在
                        plus.nativeUI.alert("非常抱歉，当前桩已停止运作，请选中其他可用桩充电。", function () {
                            mui.openWindow({
                                url: "../index/map.html",
                                id: "map"
                            });
                        }, "", "返回首页");
                        isCheckCb(false);
                        break;
                    case 21006://  电桩下线
                        plus.nativeUI.alert("当前电桩已下线，请尝试更换电桩", function () {
                            
                        }, "提示", "确定");
                        isCheckCb(false);
                    break;
                    default:
                        mui.toast(res.msg);
                        isCheckCb(false);
                }
            },
            complete: function () {
                //关闭等待框
                plus.nativeUI.closeWaiting();
            }
        });
    }
    //用户车辆被系统删除
	function carIsDeleted(){
        //先缓存选中车辆的车牌号等信息
        var chooseCarPlate = JSON.parse(plus.storage.getItem("chooseCar")).plate;

        //车辆被删除了，本地也删除掉缓存的车辆
        plus.storage.removeItem("chooseCar");

        //如果有车才去重新选择车辆，如果没有
        gAjax.$http({
            url: '/charge-app-server/app/homepage/carList',
            methods: 'get',
            success: function (res) {
                //是否需要选车
                var data = JSON.parse(Decrypt(res.data));

                // 只要有车辆 就强制去选车
                if (data.length !== 0) {
                    plus.nativeUI.confirm("当前账号下车牌为" + chooseCarPlate + "的车辆已被系统删除，请重新选择需要充电的车辆", function (index) {
 						//获得 map界面的webview
                        var mapView = plus.webview.getWebviewById('map');
                        //触发列表界面的自定义事件（refresh）,从而进行数据刷新
                        mui.fire(mapView,'reload');
                        
                        mui.openWindow('../index/map.html','map');
                    }, {
                        title: "车辆不存在",
                        buttons: ["确认"]
                    });
                }
                //如果没车，直接当做C 端用户处理
                else{
                    plus.nativeUI.confirm("当前账号系统的车辆已被清空，该账号将不再享受内部车辆充电优惠。", function (index) {
                    	plus.webview.close("car-bubble");
                    	//获得 map界面的webview
                        var mapView = plus.webview.getWebviewById('map');
                        //触发列表界面的自定义事件（refresh）,从而进行数据刷新
                        mui.fire(mapView,'reload');
                       	mui.openWindow('../index/map.html','map');
                    }, {
                        title: "车辆不存在",
                        buttons: ["确认"]
                    });
                }

            }
        });
	}
    //更新推送  clientid
    function updateClientid() {
        var info = plus.push.getClientInfo();
        //得到手机机型
        var platform = plus.os.name;
        var _user = localStorage.getItem('_user') ? JSON.parse(localStorage.getItem('_user')) : {};
        if (_user.loginToken && info.clientid != "") {
            gAjax.$http({
                url: '/charge-app-server/app/user/updateClientId',
                methods: 'POST',
                data: {
                    clientId: info.clientid,
                    phoneType: platform == "Android" ? 0 : 1
                },
                success: function (res) {
//                  console.log(res);
                }
            });
        }
    }

    //判断是否是正确的手机号
    function isPhone(str) {
        var reg = /^[1][\d]{10}$/;
        return reg.test(str)
    }

    //判断是否6位数字
    function isSixNumber(str) {
        var reg = /^\d{6}\b/;
        return reg.test(str)
    }

    //格式化手机号
    function formattePhone(value) {//153 9719 1470
        var val = value.replace(/ /g, '');
        var arr = [];
        arr[0] = val.substr(0, 3);
        arr[1] = val.substr(3, 4);
        arr[2] = val.substr(7, 4);
        return arr.join(' ').trim();
    }

    //隐藏手机号中间6位
    function hidePhone(str) {
        if (isPhone(str)) {
            var reg = new RegExp("(\\d{3})(\\d{6})(\\d{2})");
            // var reg = new RegExp("(\\d{3})(\\d{4})(\\d{4})");
            return str.replace(reg, "$1******$3");
        } else {
            console.log('手机号码不正确');
            return str;
        }
    }

    //头部红色提示框
    function topToast(test, time) {
        var hd = document.getElementsByClassName('g-header')[0];
        if (hd) {
            var toast = document.createElement("div");
            toast.append(test);
            toast.classList.add("g-toast-top");
            hd.appendChild(toast);
            setTimeout(function () {
                toast = document.getElementsByClassName('g-toast-top')[0];
                toast.parentNode.removeChild(toast);
            }, time)
        }
    }

    //Object.assign Polyfill
    if (typeof Object.assign != 'function') {
        // Must be writable: true, enumerable: false, configurable: true
        Object.defineProperty(Object, "assign", {
            value: function assign(target, varArgs) { // .length of function is 2
                'use strict';
                if (target == null) { // TypeError if undefined or null
                    throw new TypeError('Cannot convert undefined or null to object');
                }
                var to = Object(target);
                for (var index = 1; index < arguments.length; index++) {
                    var nextSource = arguments[index];
                    if (nextSource != null) { // Skip over if undefined or null
                        for (var nextKey in nextSource) {
                            // Avoid bugs when hasOwnProperty is shadowed
                            if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
                                to[nextKey] = nextSource[nextKey];
                            }
                        }
                    }
                }
                return to;
            },
            writable: true,
            configurable: true
        });
    }
    //return
    return {
        openPage: openPage,
        gCode: gCode,
		imgCode: imgCode,
        checkPortStatus: checkPortStatus,
        carIsDeleted:carIsDeleted,
        updateClientid: updateClientid,
        isPhone: isPhone,
        formattePhone: formattePhone,
        isSixNumber: isSixNumber,
        updateOrCreateByWebviewId: updateOrCreateByWebviewId,
        hidePhone: hidePhone,
        getAccount: getAccount,
        topToast: topToast,
        priceFixed:priceFixed,
        chargeBtnDisabled:chargeBtnDisabled
    }
})(mui, window, gAjax);
