/*!
* @fileoverview
*    全局的JS 文件，用来写一些公共的方法，和配置等等
*
* @Author Dehua.ke
* @Email kedh@hzzh.com
* @Date 2018/08/09
*
* Copyright 2018 中恒节能 Inc. All Rights Reserved.
*/
var ZH = ZH || {};
Object.assign(ZH, (function (MUI, WIN) {

    //起点
    // this.origin = [];
    //终点
    // this.destination = [];
    //起点终点对象
    this.navObj = {}

    function setNavObj(navObj) {
        this.navObj = navObj;
    }

    function getNavObj() {
        return this.navObj;

    }

    /**
     *  选择导航地图
     * @param origin   起点
     * @param destination    终点
     *
     * {
            origin:{
                lon:120.540,
                    lat:30.01
            },
            destination:{
                lon:120.540,
                    lat:30.01
            }
     *
     */
    function selectMapNav(navObj) {
        //设置起点和终点
        ZH.setNavObj(navObj);
        // this.navObj = navObj;//导航对象，里面包含起点终点
        // this.destination = destination;//终点
        // var installedMapList = getInstalledMapIOS();
        // console.log("装没装百度地图");
        // console.log(JSON.stringify(installedMapList));
        // return;

        // 弹出系统选择按钮框
        var btnArray = [{title: "高德地图"},{title: "百度地图"}];

        //如果是 IOS，就加一个 Apple 地图导航
//      if (plus.os.name === "iOS") {
//          btnArray.push({title: "Apple 地图"});
//      }

        plus.nativeUI.actionSheet({
            cancel: "取消",
            buttons: btnArray
        }, function (e) {
            var index = e.index;
            switch (index) {
                case 0:
                    break;
                case 1:
                    navByAMap();
                    break;
                case 2:
                    navByBaidu();
                    break;
                case 3:
                    navBySysMap();
                    break;
            }
        });
    }

    /**
     * 调用百度地图进行导航
     * */
    function navByBaidu() {
        var thisNavObj =  ZH.getNavObj();

        //起点经纬度字符串
        // var originStr = thisNavObj.origin.latitude + "," + thisNavObj.origin.longitude;
        var destinationStr = thisNavObj.baidu.latitude + "," + thisNavObj.baidu.longitude;

        //IOS
        if (plus.os.name === "iOS") {
            // WIN.open("baidumap://map/direction?origin=" +   originStr + "&destination=" + destinationStr + "&mode=driving&src=ios.baidu.openAPIdemo");
            //IOS是否安装了百度地图
            if(getInstalledMap().baidu){
                WIN.open("baidumap://map/navi?location=" + destinationStr + "&type=BLK&src=ios.baidu.openAPIdemo");
            }else{
                // mui.alert("您尚未安装百度地图","提示");
                confirmDownLoad("您尚未安装百度导航软件，是否前往下载？","itms-apps://itunes.apple.com/cn/app/id452186370?mt=8");
            }
        }
        //Android
        else if (plus.os.name === "Android") {
            //Android是否安装了百度地图
            if(getInstalledMap().baidu){
                WIN.open("baidumap://map/navi?location=" + destinationStr + "&src=andr.baidu.openAPIdemo");
            }else{
                // mui.alert("您尚未安装百度地图","提示");
                confirmDownLoad("您尚未安装百度导航软件，是否前往下载？","http://sj.qq.com/myapp/detail.htm?apkName=com.baidu.BaiduMap");
            }
        }
    }

    /**
     * 调用系统地图进行导航
     * */
    function navBySysMap() {

        var thisNavObj =  ZH.getNavObj();
        // 设置目标位置坐标点和其实位置坐标点
        var destination = new plus.maps.Point(thisNavObj.destination.longitude, thisNavObj.destination.latitude); // 终点
        var origin = new plus.maps.Point(thisNavObj.origin.longitude, thisNavObj.origin.latitude); // 起点

        //IOS
        if (plus.os.name === "iOS") {
            // 调用系统地图显示
            plus.maps.openSysMap(destination, "随便试试", origin);
        }
        //Android
        else if (plus.os.name === "Android") {
            MUI.alert("暂时不支持安卓");
        }
    }

    /**
     * 调用高德地图进行导航
     * */
    function navByAMap() {
        // http://m.amap.com/?from=39.997361,116.478346(from)&to=39.966577,116.3246(to)
        var thisNavObj =  ZH.getNavObj();
        //百度地图坐标转高德
        var amapNavObj = thisNavObj.amap;
        // var amapNavObj = ZH.BaiduAmapTransform(thisNavObj.destination.longitude, thisNavObj.destination.latitude);
        // var amapNavObj = thisNavObj.destination;
        //起点经纬度字符串
        // var originStr = thisNavObj.origin.latitude + "," + thisNavObj.origin.longitude;
        // var destinationStr = thisNavObj.destination.latitude + "," + thisNavObj.destination.longitude;

        //IOS
        if (plus.os.name === "iOS") {
            //IOS是否安装了高德地图
            if(getInstalledMap().amap){

                WIN.open("iosamap://navi?sourceApplication=applicationName&poiname=fangheng&poiid=BGVIS&lat="+ amapNavObj.latitude +"&lon="+ amapNavObj.longitude +"&dev=0&style=2");
                // WIN.open("iosamap://navi?sourceApplication=applicationName&poiname=fangheng&poiid=BGVIS&lat="+ amapNavObj.latitude +"&lon="+ amapNavObj.longitude +"&dev=1&style=2");
                // WIN.open("iosamap://navi?sourceApplication=applicationName&poiname=fangheng&poiid=BGVIS&lat="+ amapNavObj[1] +"&lon="+ amapNavObj[0] +"&dev=1&style=2");
            }else{
                // mui.alert("您尚未安装高德地图","提示");
                confirmDownLoad("您尚未安装高德导航软件，是否前往下载？","itms-apps://itunes.apple.com/cn/app/id461703208?mt=8");
            }
        }
        //Android
        else if (plus.os.name === "Android") {
            //Android是否安装了高德地图
            if(getInstalledMap().amap){
                WIN.open("androidamap://navi?sourceApplication=appname&poiname=fangheng&lat="+ amapNavObj.latitude +"&lon="+ amapNavObj.longitude +"&dev=0&style=2");
            }else{
                // mui.alert("您尚未安装高德地图","提示");
                confirmDownLoad("您尚未安装高德导航软件，是否前往下载？","http://sj.qq.com/myapp/detail.htm?apkName=com.autonavi.minimap");

            }
        }
    }

    /**
     *   询问用户是否去下载应用
     */
    function confirmDownLoad(issue,downURL) {

        // mui.alert("您尚未安装高德地图","提示");
        plus.nativeUI.confirm(" ", function (event) {
            //前往下载
            if(event.index === 1){
                //452186370
                plus.runtime.openURL(downURL);
            }
        }, {
            title: issue,
            buttons: ["取消","前往下载"],
        });

    }

    /**
     *  是否安装了百度地图，高德地图
     */
    function getInstalledMap() {

        //IOS
        if (plus.os.name === "iOS") {
            return {
                baidu: IOSisInstalledByScheme("baidumap://"),
                amap: IOSisInstalledByScheme("iosamap://")
            }
        }
        //Android
        else if (plus.os.name === "Android") {
            return {
                baidu: ANDROIDisInstalledByPackageName("com.baidu.BaiduMap"),
                amap: ANDROIDisInstalledByPackageName("com.autonavi.minimap")
            }
        }
    }

    /**
     *
     *      Android 是否安装了百度地图，高德地图
     *  @param  packageName  根据包名来判断是否安装该应用
     *  @return  Boolean    true | false     已安装|未安装
     *
     */
    function ANDROIDisInstalledByPackageName(packageName) {
        try {
            var main = plus.android.runtimeMainActivity();
            var packageManager = main.getPackageManager();
            var PackageManager = plus.android.importClass(packageManager);
            var packageInfo = packageManager.getPackageInfo(packageName, PackageManager.GET_ACTIVITIES);
            if (packageInfo) {
                    //已安装
                return true;
            } else {
                   //未安装
                return false;
            }
        } catch (e) {
               //未安装
            return false;
        }
    }

    /**
     *  IOS 根据 Scheme 来判断是否安装某一个应用
     */
    function IOSisInstalledByScheme(scheme) {
        var UIApplication = plus.ios.importClass("UIApplication");
        var NSURL = plus.ios.importClass("NSURL");

        var app = UIApplication.sharedApplication();
        var bdScheme = NSURL.URLWithString(scheme);
        var install = app.canOpenURL(bdScheme);

        plus.ios.deleteObject(bdScheme);
        plus.ios.deleteObject(app);

        return install;
    }


    //百度坐标转高德（传入经度、纬度）
    function baiduToAmap(bd_lng, bd_lat) {
        var X_PI = Math.PI * 3000.0 / 180.0;
        var x = bd_lng - 0.0065;
        var y = bd_lat - 0.006;
        var z = Math.sqrt(x * x + y * y) - 0.00002 * Math.sin(y * X_PI);
        var theta = Math.atan2(y, x) - 0.000003 * Math.cos(x * X_PI);
        var gg_lng = z * Math.cos(theta);
        var gg_lat = z * Math.sin(theta);
        return {lng: gg_lng, lat: gg_lat}
    }
    //高德坐标转百度（传入经度、纬度）
    function amapTobaidu(gg_lng, gg_lat) {
        var X_PI = Math.PI * 3000.0 / 180.0;
        var x = gg_lng, y = gg_lat;
        var z = Math.sqrt(x * x + y * y) + 0.00002 * Math.sin(y * X_PI);
        var theta = Math.atan2(y, x) + 0.000003 * Math.cos(x * X_PI);
        var bd_lng = z * Math.cos(theta) + 0.0065;
        var bd_lat = z * Math.sin(theta) + 0.006;
        return {
            bd_lat: bd_lat,
            bd_lng: bd_lng
        };
    }

    /**
     * 是否开启 GPS
     *
     * @return  Boolean   true|false    开启|关闭
     */
    function gpsIsEnabled() {
        //iOS
        if(plus.os.name === "iOS"){
            //IOS GPS 不能关闭 ，所以直接返回 true
            return true;
        }
        //Android
        else if(plus.os.name === "Android"){
            var context = plus.android.importClass("android.content.Context");
            var locationManager=plus.android.importClass("android.location.LocationManager");
            var main=plus.android.runtimeMainActivity();
            var mainSvr=main.getSystemService(context.LOCATION_SERVICE);
            return mainSvr.isProviderEnabled(locationManager.GPS_PROVIDER);
        }

    }


        //return
    return {
        selectMapNav: selectMapNav,
        navByBaidu: navByBaidu,
        setNavObj: setNavObj,
        getNavObj: getNavObj,
        gpsIsEnabled: gpsIsEnabled,
        navByAMap: navByAMap
    }
})(mui, window));
