/*!
* @fileoverview
*    全局的JS 文件，用来写一些公共的方法，和配置等等
*
* @Author Dehua.ke
* @Email kedh@hzzh.com
* @Date 2018/08/09
*
* Copyright 2018 中恒节能 Inc. All Rights Reserved.
*/
var ZH = ZH || {};
Object.assign(ZH, (function (MUI, WIN) {

    //起点
    // this.origin = [];
    //终点
    // this.destination = [];
    //起点终点对象
    this.navObj = {}

    function setNavObj(navObj) {
        this.navObj = navObj;
    }

    function getNavObj() {
        return this.navObj;

    }

    /**
     *  选择导航地图
     * @param origin   起点
     * @param destination    终点
     *
     * {
            origin:{
                lon:120.540,
                    lat:30.01
            },
            destination:{
                lon:120.540,
                    lat:30.01
            }
     *
     */
    function selectMapNav(navObj) {
        //设置起点和终点
        ZH.setNavObj(navObj);
        // this.navObj = navObj;//导航对象，里面包含起点终点
        // this.destination = destination;//终点

        // 弹出系统选择按钮框
        var btnArray = [{title: "高德地图"},{title: "百度地图"}];

        //如果是 IOS，就加一个 Apple 地图导航
//      if (plus.os.name === "iOS") {
//          btnArray.push({title: "Apple 地图"});
//      }

        plus.nativeUI.actionSheet({
            cancel: "取消",
            buttons: btnArray
        }, function (e) {
            var index = e.index;
            switch (index) {
                case 0:
                    break;
                case 1:
                    navByAMap();
                    break;
                case 2:
                    navByBaidu();
                    break;
                case 3:
                    navBySysMap();
                    break;
            }
        });
    }

    /**
     * 调用百度地图进行导航
     * */
    function navByBaidu() {
        var thisNavObj =  ZH.getNavObj();

        //起点经纬度字符串
        // var originStr = thisNavObj.origin.latitude + "," + thisNavObj.origin.longitude;
        var destinationStr = thisNavObj.destination.latitude + "," + thisNavObj.destination.longitude;

        //IOS
        if (plus.os.name === "iOS") {
            // WIN.open("baidumap://map/direction?origin=" +   originStr + "&destination=" + destinationStr + "&mode=driving&src=ios.baidu.openAPIdemo");
            WIN.open("baidumap://map/navi?location=" + destinationStr + "&type=BLK&src=ios.baidu.openAPIdemo");

        }
        //Android
        else if (plus.os.name === "Android") {
               WIN.open("baidumap://map/navi?location=" + destinationStr + "&src=andr.baidu.openAPIdemo");
        }
    }

    /**
     * 调用系统地图进行导航
     * */
    function navBySysMap() {
    	
        var thisNavObj =  ZH.getNavObj();
        console.log("thisNavObjthisNavObjthisNavObj");
        console.log(JSON.stringify(thisNavObj));
        //起点经纬度字符串
        // var originStr = thisNavObj.origin.latitude + "," + thisNavObj.origin.longitude;
        // var destinationStr = thisNavObj.destination.latitude + "," + thisNavObj.destination.longitude;
        // 设置目标位置坐标点和其实位置坐标点
        var destination = new plus.maps.Point(thisNavObj.destination.longitude, thisNavObj.destination.latitude); // 终点
        var origin = new plus.maps.Point(thisNavObj.origin.longitude, thisNavObj.origin.latitude); // 起点

        //IOS
        if (plus.os.name === "iOS") {
            // 调用系统地图显示
            plus.maps.openSysMap(destination, "随便试试", origin);

        }
        //Android
        else if (plus.os.name === "Android") {
            MUI.alert("暂时不支持安卓");
        }
    }

    /**
     * 调用高德地图进行导航
     * */
    function navByAMap() {
        // http://m.amap.com/?from=39.997361,116.478346(from)&to=39.966577,116.3246(to)
        var thisNavObj =  ZH.getNavObj();
        //起点经纬度字符串
        // var originStr = thisNavObj.origin.latitude + "," + thisNavObj.origin.longitude;
        // var destinationStr = thisNavObj.destination.latitude + "," + thisNavObj.destination.longitude;

        //IOS
        if (plus.os.name === "iOS") {
            WIN.open("iosamap://navi?sourceApplication=applicationName&poiname=fangheng&poiid=BGVIS&lat="+ thisNavObj.destination.latitude +"&lon="+ thisNavObj.destination.longitude +"&dev=1&style=2");
        }
        //Android
        else if (plus.os.name === "Android") {
            WIN.open("androidamap://navi?sourceApplication=appname&poiname=fangheng&lat="+ thisNavObj.destination.latitude +"&lon="+ thisNavObj.destination.longitude +"&dev=1&style=2");
        }
    }


    //return
    return {
        selectMapNav: selectMapNav,
        navByBaidu: navByBaidu,
        setNavObj: setNavObj,
        getNavObj: getNavObj,
        navByAMap: navByAMap
    }
})(mui, window));
